# Table of Contents

- [jira-integration](<./jira-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Jira Integration](<./Jira-Integration.md>)
  - [Overview](<./Jira-Integration/Overview.md>)
  - [Benefits](<./Jira-Integration/Benefits.md>)
  - [Scope and Limitations](<./Jira-Integration/Scope-and-Limitations.md>)
  - [Setting Up the Integration](<./Jira-Integration/Setting-Up-the-Integration.md>)
  - [API Endpoints Used by the Integration](<./Jira-Integration/API-Endpoints-Used-by-the-Integration.md>)
  - [Syncing Data Between Jira and SAP LeanIX](<./Jira-Integration/Syncing-Data-Between-Jira-and-SAP-LeanIX.md>)
  - [Tracking Progress on Linked Jira Work Items](<./Jira-Integration/Tracking-Progress-on-Linked-Jira-Work-Items.md>)
  - [Syncing Jira Data Manually](<./Jira-Integration/Syncing-Jira-Data-Manually.md>)
  - [Was this page helpful?](<./Jira-Integration/Was-this-page-helpful.md>)
